#    Back In Time
#    Copyright (C) 2010 Ryan Ahearn
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License along
#    with this program; if not, write to the Free Software Foundation, Inc.,
#    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
	

import os.path
import sys
import urwid
import gettext

sys.path = [os.path.join( os.path.dirname( os.path.abspath( os.path.dirname( __file__ ) ) ), 'common' )] + sys.path

import backintime
import config
import logger
import guiapplicationinstance
import profilewidget
import generalwidget
import includewidget
import excludewidget
import removewidget
import optionswidget
import expertwidget

_=gettext.gettext

class MainWindow(object):

    def __init__( self, config ):
        self._config = config

        self._header = _('Back in Time Configuration') + '.  ' + _('F6 exits')
        setting_sections = [ "Profiles", "General", "Include", "Exclude", "Auto-remove", "Options", "Expert Options" ]
        self._listbox_content = [
            urwid.Divider(),                                                # position 0
            urwid.Text( _("Profile") + ": " + config.get_profile_name() ),  # position 1
            urwid.Divider(),                                                # position 2
            urwid.GridFlow( [ urwid.AttrWrap( urwid.Button( _(txt), self.sections_button_press, txt ), 'button', 'button_focus' ) for txt in setting_sections ],
                           18, 2, 1, 'center' ),                            # position 3
            urwid.Divider(),                                                # position 4
            profilewidget.ProfileWidget( self, config ),                    # position 5
            ]

    def sections_button_press( self, button, user_data ):
        if user_data == 'Profiles':
            widget = profilewidget.ProfileWidget( self, self._config )
        elif user_data == 'General':
            widget = generalwidget.GeneralWidget( self, self._config )
        elif user_data == 'Include':
            widget = includewidget.IncludeWidget( self, self._config )
        elif user_data == 'Exclude':
            widget = excludewidget.ExcludeWidget( self, self._config )
        elif user_data == 'Auto-remove':
            widget = removewidget.RemoveWidget( self._config )
        elif user_data == 'Options':
            widget = optionswidget.OptionsWidget( self._config )
        elif user_data == 'Expert Options':
            widget = expertwidget.ExpertOptionsWidget( self._config )
        self.update_content( widget, 5 )

    def show( self ):
        header = urwid.AttrWrap( urwid.Text( self._header, align='center' ), 'header' )
        self._content = urwid.SimpleListWalker( self._listbox_content )
        self._listbox = urwid.ListBox( self._content )
        frame = urwid.Frame( urwid.AttrWrap( self._listbox, 'body' ), header=header )

        palette = [
            ( 'body', 'black', 'light gray', 'standout' ),
            ( 'error', 'dark red', 'light gray', 'bold' ),
            ( 'header', 'white', 'dark red', 'bold' ),
            ( 'button', 'black', 'dark cyan' ),
            ( 'button_focus', 'white', 'dark blue', 'bold' ),
            ( 'edit_box', 'light gray', 'dark blue' ),
            ( 'edit_focus', 'white', 'dark blue', 'bold' )
            ]

        urwid.MainLoop( frame, palette, unhandled_input=self.unhandled_input ).run()

    def update_content( self, widget, position ):
        self._content[position] = widget

    def update_profile_name( self ):
        self.update_content( urwid.Text( _('Profile') + ': ' + self._config.get_profile_name() ), 1 )
        
    def unhandled_input( self, key ):
        if key == 'f6':
            self.on_close()

    def on_close( self ):
        self.update_content( ConfirmSave( self._config ), 5 )

class ConfirmSave(urwid.WidgetWrap):

    def __init__( self, config ):
        self._config = config

        pile_list = [
            urwid.Padding( urwid.Text( _('Save configuration?') ), 'center' ),
            urwid.Divider(),
            urwid.GridFlow( [
                urwid.AttrWrap( urwid.Button( _('Yes'), self.save ), 'button', 'button_focus' ),
                urwid.AttrWrap( urwid.Button( _('No'), self.close ), 'button', 'button_focus' )
                ], 10, 2, 1, 'center' )
            ]

        display_widget = urwid.Pile( pile_list )
        urwid.WidgetWrap.__init__( self, display_widget )

    def save( self, button ):
        self._config.save()
        self._config.setup_cron()
        self.close()

    def close( self, button=None ):
        raise urwid.ExitMainLoop()
        
if __name__ == '__main__':
    cfg = backintime.start_app( 'backintime-config' )
    raise_cmd = ''
    if len( sys.argv ) > 1:
        raise_cmd = '\n'.join( sys.argv[ 1 : ] )
    app_instance = guiapplicationinstance.GUIApplicationInstance( cfg.get_app_instance_file(), raise_cmd )

    logger.openlog()
    main_window = MainWindow( cfg )
    main_window.show()
    logger.closelog()

    app_instance.exit_application()
