#    Back In Time
#    Copyright (C) 2010 Ryan Ahearn
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License along
#    with this program; if not, write to the Free Software Foundation, Inc.,
#    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
	

import os.path
import sys
import urwid
import gettext

sys.path = [os.path.join( os.path.dirname( os.path.abspath( os.path.dirname( __file__ ) ) ), 'common' )] + sys.path

import backintime
import config
import logger
import guiapplicationinstance
import profilewidget
import restorewidget
import removesnapshot
import snapshotname

_=gettext.gettext

class MainWindow(object):

    def __init__( self, config ):
        self._config = config
        self.selected_snapshot = ''
        self.selected_snapshot_name = ''
        self.current_directory = config.get_str_value( 'cli.last_path', '/' )
        self.show_hidden = False
        
        self._header = _('Back in Time Restore Utility') + '.  ' + _('F6 exits')
        self._profile_button = urwid.Button( config.get_profile_name(), self.change_profile )
        buttons = [ 'Take Snapshot', 'Update Snapshots', 'Snapshot Name', 'Remove Snapshot' ]
        self._listbox_content = [
            urwid.Divider(),                                                    # position 0
            urwid.AttrWrap( self._profile_button, 'button', 'button_focus' ),   # position 1
            urwid.Divider(),                                                    # position 2
            urwid.GridFlow( [ urwid.AttrWrap( urwid.Button( _(txt), self.button_press, txt ), 'button', 'button_focus' ) for txt in buttons ],
                           20, 2, 1, 'center' ),                                # position 3
            urwid.Divider(),                                                    # position 4
            restorewidget.RestoreWidget( self, config ),                        # position 5
            ]

    def change_profile( self, button ):
        self.update_content( profilewidget.ProfileWidget( self, self._config, False ), 5 )

    def button_press( self, button, user_data ):
        if user_data == 'Take Snapshot':
            backintime.take_snapshot_now_async( self._config )
        elif user_data == 'Update Snapshots':
            self.update_content( restorewidget.RestoreWidget( self, self._config ), 5 )
        elif user_data == 'Snapshot Name' and self.selected_snapshot != '':
            self.update_content( snapshotname.SnapshotName( self, self._config ), 5 )
        elif user_data == 'Remove Snapshot' and self.selected_snapshot != '':
            self.update_content( removesnapshot.RemoveSnapshot( self, self._config ), 5 )

    def show( self ):
        header = urwid.AttrWrap( urwid.Text( self._header, align='center' ), 'header' )
        self._content = urwid.SimpleListWalker( self._listbox_content )
        self._listbox = urwid.ListBox( self._content )
        frame = urwid.Frame( urwid.AttrWrap( self._listbox, 'body' ), header=header )

        palette = [
            ( 'body', 'black', 'light gray', 'standout' ),
            ( 'error', 'dark red', 'light gray', 'bold' ),
            ( 'header', 'white', 'dark red', 'bold' ),
            ( 'button', 'black', 'dark cyan' ),
            ( 'button_focus', 'white', 'dark blue', 'bold' ),
            ( 'edit_box', 'light gray', 'dark blue' ),
            ( 'edit_focus', 'white', 'dark blue', 'bold' )
            ]

        self.main_loop = urwid.MainLoop( frame, palette, unhandled_input=self.unhandled_input )
        self.main_loop.run()

    def update_content( self, widget, position ):
        self._content[position] = widget

    def update_profile_name( self ):
        self._profile_button.set_label( self._config.get_profile_name() )
        self.selected_snapshot = ''
        self.update_content( restorewidget.RestoreWidget( self, self._config ), 5 )

    def update_current_directory( self, new_directory ):
        self.current_directory = new_directory
        self._config.set_str_value( 'cli.last_path', new_directory )
        self.update_content( restorewidget.RestoreWidget( self, self._config ), 5 )

    def is_selected_snapshot( self, snapshot ):
        if self.selected_snapshot == snapshot:
            return True
        else:
            return False

    def unhandled_input( self, key ):
        if key == 'f6':
            self.on_close()

    def on_close( self ):
        self._config.save()
        raise urwid.ExitMainLoop()

        
if __name__ == '__main__':
    cfg = backintime.start_app( 'backintime-restore' )
    raise_cmd = ''
    if len( sys.argv ) > 1:
        raise_cmd = '\n'.join( sys.argv[ 1 : ] )
    app_instance = guiapplicationinstance.GUIApplicationInstance( cfg.get_app_instance_file(), raise_cmd )

    logger.openlog()
    main_window = MainWindow( cfg )
    main_window.show()
    logger.closelog()

    app_instance.exit_application()
