#    Back In Time
#    Copyright (C) 2010 Ryan Ahearn
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License along
#    with this program; if not, write to the Free Software Foundation, Inc.,
#    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

import urwid
import gettext

import logger

_=gettext.gettext

class ExcludeWidget(urwid.WidgetWrap):
    
    def __init__( self, main_win, config ):
        self._main_win = main_win
        self._config = config
        self._to_delete = None

        all_patterns = config.get_exclude_patterns()
        if len( all_patterns ) == 0:
            chooser = urwid.Divider()
        else:
            excluded_patterns = []
            for pattern in all_patterns:
                urwid.RadioButton( excluded_patterns, pattern, False, self.pattern_selected )
            chooser = urwid.Pile( excluded_patterns )

        pile_list = [
            urwid.Text( _('Patterns, files or folders') ),
            urwid.Divider(),
            chooser,
            urwid.Divider(),
            urwid.GridFlow([
                urwid.AttrWrap( urwid.Button( _('Add'), self.add_pattern ), 'button', 'button_focus' ),
                urwid.AttrWrap( urwid.Button( _('Delete'), self.delete_pattern ), 'button', 'button_focus' ),
                ], 10, 2, 1, 'center' )
            ]

        display_widget = urwid.Pile( pile_list )
        urwid.WidgetWrap.__init__( self, display_widget )

    def pattern_selected( self, button, new_state ):
        if new_state:
            self._to_delete = button.get_label()

    def add_pattern( self, button ):
        self._main_win.update_content( AddExcludeWidget( self._main_win, self._config ), 5 )

    def delete_pattern( self, button ):
        if self._to_delete is not None:
            self._main_win.update_content( DeleteExcludeWidget( self._main_win, self._config, self._to_delete ), 5 )

    def go_to_exclude_patterns( self, button=None ):
        self._main_win.update_content( ExcludeWidget( self._main_win, self._config ), 5 )


class AddExcludeWidget(ExcludeWidget):

    def __init__( self, main_win, config ):
        self._main_win = main_win
        self._config = config

        self._edit_box = urwid.Edit(( 'body', _('Enter pattern, file, or folder to exclude') + ': ' ))
        pile_list = [
            urwid.AttrWrap( self._edit_box, 'edit_box', 'edit_focus' ),
            urwid.Divider(),
            urwid.GridFlow( [
                urwid.AttrWrap( urwid.Button( _('OK'), self.ok_pressed ), 'button', 'button_focus' ),
                urwid.AttrWrap( urwid.Button( _('Cancel'), self.go_to_exclude_patterns ), 'button', 'button_focus' )
                ], 10, 2, 1, 'right' )
            ]

        display_widget = urwid.Pile( pile_list )
        urwid.WidgetWrap.__init__( self, display_widget )

    def ok_pressed( self, button ):
        all_patterns = self._config.get_exclude_patterns()
        all_patterns.append( self._edit_box.get_edit_text().strip() )
        self._config.set_exclude_patterns( all_patterns )
        self.go_to_exclude_patterns()

class DeleteExcludeWidget(ExcludeWidget):
    
    def __init__( self, main_win, config, to_delete ):
        self._main_win = main_win
        self._config = config
        self._to_delete = to_delete

        pile_list = [
            urwid.Text( _('Are you sure you want to remove') + ' "' + to_delete + '" ' + _('from the excluded patterns?') ),
            urwid.Divider(),
            urwid.GridFlow( [
                urwid.AttrWrap( urwid.Button( _('Yes'), self.yes_pressed ), 'button', 'button_focus' ),
                urwid.AttrWrap( urwid.Button( _('No'), self.go_to_exclude_patterns ), 'button', 'button_focus' )
                ], 10, 2, 1, 'right' )
            ]

        display_widget = urwid.Pile( pile_list )
        urwid.WidgetWrap.__init__( self, display_widget )

    def yes_pressed( self, button ):
        all_patterns = self._config.get_exclude_patterns()
        all_patterns.remove( self._to_delete )
        self._config.set_exclude_patterns( all_patterns )
        self.go_to_exclude_patterns()
