#    Back In Time
#    Copyright (C) 2010 Ryan Ahearn
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License along
#    with this program; if not, write to the Free Software Foundation, Inc.,
#    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

import urwid
import gettext

import logger

_=gettext.gettext

class GeneralWidget(urwid.WidgetWrap):

    def __init__( self, main_win, config ):
        self._config = config
        self._main_win = main_win

        backup_mode = config.get_automatic_backup_mode()
        backup_modes = []
        for key, value in sorted( config.AUTOMATIC_BACKUP_MODES.items() ):
            if backup_mode == key:
                urwid.RadioButton( backup_modes, value, True, self.schedule_changed, key )
            else:
                urwid.RadioButton( backup_modes, value, False, self.schedule_changed, key )
        schedule_chooser = urwid.Pile( backup_modes )

        location = urwid.Edit(( 'body', _('Where to save snapshots') + ': ' ), config.get_snapshots_path() )
        urwid.connect_signal( location, 'change', self.location_changed )
        self._error = urwid.Text( '' )
        pile_list = [
            urwid.AttrWrap( location, 'edit_box', 'edit_focus' ),
            urwid.AttrWrap( self._error, 'error' ),
            urwid.Divider()
            ]
        
        if backup_mode > config.HOUR:
            # display chooser to set hour of the day to run the cron job
            set_hour = config.get_automatic_backup_time()
            hour_choices = []
            for i in range( 24 ):
                if set_hour == i:
                    urwid.RadioButton( hour_choices, ( "%2d:00" % i ), True, self.time_changed, i )
                else:
                    urwid.RadioButton( hour_choices, ( "%2d:00" % i ), False, self.time_changed, i )
            hour_chooser = urwid.Pile( hour_choices )
            pile_list.append(
                urwid.Columns( [
                    urwid.Pile( [
                        urwid.Text( _('Schedule') ),
                        schedule_chooser
                        ] ),
                    urwid.Pile( [
                        urwid.Text( _('Hour') ),
                        hour_chooser
                        ] )
                    ], 1 )
                )
        else:
            pile_list.extend( [
                urwid.Text( _('Schedule') ),
                schedule_chooser
                ] )

        display_widget = urwid.Pile( pile_list )
        urwid.WidgetWrap.__init__( self, display_widget )

    def schedule_changed( self, check_box, new_state, user_data ):
        if new_state:
            self._config.set_automatic_backup_mode( user_data )
            self._main_win.update_content( GeneralWidget( self._main_win, self._config ), 5 )

    def time_changed( self, check_box, new_state, user_data ):
        if new_state:
            self._config.set_automatic_backup_time( user_data )

    def location_changed( self, edit, new_edit_text ):
        if not self._config.set_snapshots_path( new_edit_text.strip() ):
            self._error.set_text( _('Could not use this path, are you sure it exists and you have write access?') )
        else:
            self._error.set_text( '' )
