#    Back In Time
#    Copyright (C) 2010 Ryan Ahearn
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License along
#    with this program; if not, write to the Free Software Foundation, Inc.,
#    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

import urwid
import gettext

import logger

_=gettext.gettext

class IncludeWidget(urwid.WidgetWrap):
    
    def __init__( self, main_win, config ):
        self._main_win = main_win
        self._config = config
        self._to_delete = None

        all_folders = config.get_include_folders()
        if len( all_folders ) == 0:
            chooser = urwid.Divider()
        else:
            included_folders = []
            for folder in all_folders:
                urwid.RadioButton( included_folders, folder, False, self.folder_selected )
            chooser = urwid.Pile( included_folders )

        pile_list = [
            urwid.Text( _('Include Folders') ),
            urwid.Divider(),
            chooser,
            urwid.Divider(),
            urwid.GridFlow( [
                urwid.AttrWrap( urwid.Button( _('Add'), self.add_folder ), 'button', 'button_focus' ),
                urwid.AttrWrap( urwid.Button( _('Delete'), self.delete_folder ), 'button', 'button_focus' ),
                ], 10, 2, 1, 'center' )
            ]

        display_widget = urwid.Pile( pile_list )
        urwid.WidgetWrap.__init__( self, display_widget )

    def folder_selected( self, button, new_state ):
        if new_state:
            self._to_delete = button.get_label()

    def add_folder( self, button ):
        self._main_win.update_content( AddIncludeWidget( self._main_win, self._config ), 5 )

    def delete_folder( self, button ):
        if self._to_delete is not None:
            self._main_win.update_content( DeleteIncludeWidget( self._main_win, self._config, self._to_delete ), 5 )

    def go_to_include_folders( self, button=None ):
        self._main_win.update_content( IncludeWidget( self._main_win, self._config ), 5 )


class AddIncludeWidget(IncludeWidget):

    def __init__( self, main_win, config ):
        self._main_win = main_win
        self._config = config

        self._edit_box = urwid.Edit(( 'body', _('Enter path for folder to backup') + ': ' ))
        pile_list = [
            urwid.AttrWrap( self._edit_box, 'edit_box', 'edit_focus' ),
            urwid.Divider(),
            urwid.GridFlow( [
                urwid.AttrWrap( urwid.Button( _('OK'), self.ok_pressed ), 'button', 'button_focus' ),
                urwid.AttrWrap( urwid.Button( _('Cancel'), self.go_to_include_folders ), 'button', 'button_focus' )
                ], 10, 2, 1, 'right' )
            ]

        display_widget = urwid.Pile( pile_list )
        urwid.WidgetWrap.__init__( self, display_widget )

    def ok_pressed( self, button ):
        all_folders = self._config.get_include_folders()
        all_folders.append( self._edit_box.get_edit_text().strip() )
        self._config.set_include_folders( all_folders )
        self.go_to_include_folders()

class DeleteIncludeWidget(IncludeWidget):
    
    def __init__( self, main_win, config, to_delete ):
        self._main_win = main_win
        self._config = config
        self._to_delete = to_delete

        pile_list = [
            urwid.Text( _('Are you sure you want to remove') + ' "' + to_delete + '" ' + _('from the backed up folders?') ),
            urwid.Divider(),
            urwid.GridFlow( [
                urwid.AttrWrap( urwid.Button( _('Yes'), self.yes_pressed ), 'button', 'button_focus' ),
                urwid.AttrWrap( urwid.Button( _('No'), self.go_to_include_folders ), 'button', 'button_focus' )
                ], 10, 2, 1, 'right' )
            ]

        display_widget = urwid.Pile( pile_list )
        urwid.WidgetWrap.__init__( self, display_widget )

    def yes_pressed( self, button ):
        all_folders = self._config.get_include_folders()
        all_folders.remove( self._to_delete )
        self._config.set_include_folders( all_folders )
        self.go_to_include_folders()
