#    Back In Time
#    Copyright (C) 2010 Ryan Ahearn
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License along
#    with this program; if not, write to the Free Software Foundation, Inc.,
#    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

import urwid
import gettext

import logger

_=gettext.gettext

class ProfileWidget(urwid.WidgetWrap):
    
    def __init__( self, main_win, config, display_buttons=True ):
        self._main_win = main_win
        self._config = config

        current_profile = config.get_current_profile()
        profile_ids = config.get_profiles()
        profiles = []
        for profile_id in profile_ids:
            profile_name = config.get_profile_name( profile_id )
            if profile_id == current_profile:
                urwid.RadioButton( profiles, profile_name, True, self.profile_changed, profile_id )
            else:
                urwid.RadioButton( profiles, profile_name, False, self.profile_changed, profile_id )
        chooser = urwid.Pile( profiles )

        pile_list = [
            urwid.Text( _('Choose a profile') ),
            urwid.Divider(),
            chooser,
            urwid.Divider()
            ]

        if display_buttons:
            buttons = [
                urwid.Button( _('Edit'), self.edit_profile ),
                urwid.Button( _('New'), self.add_profile )
                ]
            if len( profile_ids ) > 1:
                buttons.append( urwid.Button( _('Delete'), self.delete_profile ) )
            pile_list.append( urwid.GridFlow( [ urwid.AttrWrap( button, 'button', 'button_focus' ) for button in buttons ], 10, 2, 1, 'center' ) )
            
        display_widget = urwid.Pile( pile_list )
        urwid.WidgetWrap.__init__( self, display_widget )

    def profile_changed( self, button, new_state, user_data ):
        if new_state:
            self._config.set_current_profile( user_data )
            self._main_win.update_profile_name()

    def add_profile( self, button ):
        self._main_win.update_content( AddProfileWidget( self._main_win, self._config ), 5 )

    def edit_profile( self, button ):
        self._main_win.update_content( EditProfileWidget( self._main_win, self._config ), 5 )
        
    def delete_profile( self, button ):
        self._main_win.update_content( DeleteProfileWidget( self._main_win, self._config ), 5 )

    def go_to_profile_list( self, button=None ):
        self._main_win.update_profile_name()
        self._main_win.update_content( ProfileWidget( self._main_win, self._config ), 5 )


class EditProfileWidget(ProfileWidget):

    def __init__( self, main_win, config ):
        self._main_win = main_win
        self._config = config

        self._edit_box = urwid.Edit(( 'body', _('Enter new name for profile') + ' ' + config.get_profile_name() + ': ' ))
        self._error = urwid.Text( '' )
        pile_list = [
            urwid.AttrWrap( self._edit_box, 'edit_box', 'edit_focus' ),
            urwid.AttrWrap( self._error, 'error' ),
            urwid.Divider(),
            urwid.GridFlow( [
                urwid.AttrWrap( urwid.Button( _('OK'), self.ok_pressed ), 'button', 'button_focus' ),
                urwid.AttrWrap( urwid.Button( _('Cancel'), self.go_to_profile_list ), 'button', 'button_focus' )
                ], 10, 2, 1, 'right' )
            ]

        display_widget = urwid.Pile( pile_list )
        urwid.WidgetWrap.__init__( self, display_widget )

    def ok_pressed( self, button ):
        name = self._edit_box.get_edit_text().strip()
        if name == '':
            self._error.set_text( _('Profile must be given a name') )
        elif self._config.set_profile_name( name ):
            self.go_to_profile_list()
        else:
            self._error.set_text( _('Profile name already exists, choose another') )

            
class AddProfileWidget(ProfileWidget):

    def __init__( self, main_win, config ):
        self._main_win = main_win
        self._config = config
        
        self._edit_box = urwid.Edit(( 'body', _('Enter name for new profile') + ': ' ))
        self._error = urwid.Text( '' )
        pile_list = [
            urwid.AttrWrap( self._edit_box, 'edit_box', 'edit_focus' ),
            urwid.AttrWrap( self._error, 'error' ),
            urwid.Divider(),
            urwid.GridFlow([
                urwid.AttrWrap( urwid.Button( _('OK'), self.ok_pressed ), 'button', 'button_focus' ),
                urwid.AttrWrap( urwid.Button( _('Cancel'), self.go_to_profile_list ), 'button', 'button_focus' )
                ], 10, 2, 1, 'right' )
            ]

        display_widget = urwid.Pile( pile_list )
        urwid.WidgetWrap.__init__( self, display_widget )

    def ok_pressed( self, button ):
        name = self._edit_box.get_edit_text().strip()
        if name == '':
            self._error.set_text( _('Profile must be given a name') )
        elif self._config.add_profile( name ):
            self.go_to_profile_list()
        else:
            self._error.set_text( _('Profile name already exists, choose another') )

        
class DeleteProfileWidget(ProfileWidget):

    def __init__( self, main_win, config ):
        self._main_win = main_win
        self._config = config

        pile_list = [
            urwid.Text( _('Are You Sure you want to delete profile') + ' "' + config.get_profile_name() + '"' ),
            urwid.Divider(),
            urwid.GridFlow([
                urwid.AttrWrap( urwid.Button( _('Yes'), self.yes_pressed ), 'button', 'button_focus' ),
                urwid.AttrWrap( urwid.Button( _('No'), self.go_to_profile_list ), 'button', 'button_focus' )
                ], 10, 2, 1, 'right' )
            ]

        display_widget = urwid.Pile( pile_list )
        urwid.WidgetWrap.__init__( self, display_widget )

    def yes_pressed( self, button ):
        self._config.remove_profile()
        self.go_to_profile_list()
