#    Back In Time
#    Copyright (C) 2010 Ryan Ahearn
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License along
#    with this program; if not, write to the Free Software Foundation, Inc.,
#    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

import urwid
import gettext

import logger

_=gettext.gettext

class RemoveWidget(urwid.WidgetWrap):

    def __init__( self, config ):
        self._config = config

        old_enabled, self._remove_old_value, self._remove_old_unit = config.get_remove_old_snapshots()
        self._remove_old_enabled = urwid.CheckBox( _('Older than:'), old_enabled, on_state_change=self.flip_old_enabled )
        remove_old_value_box = urwid.IntEdit( '', self._remove_old_value )
        urwid.connect_signal( remove_old_value_box, 'change', self.remove_old_value_changed )
        remove_units = []
        for key, value in sorted( config.REMOVE_OLD_BACKUP_UNITS.items() ):
            if self._remove_old_unit == key:
                urwid.RadioButton( remove_units, value, True, self.remove_old_unit_changed, key )
            else:
                urwid.RadioButton( remove_units, value, False, self.remove_old_unit_changed, key )
        remove_unit_chooser = urwid.Pile( remove_units )
        age_columns = urwid.Columns( [
            self._remove_old_enabled,
            urwid.AttrWrap( remove_old_value_box, 'edit_box', 'edit_focus' ),
            remove_unit_chooser
            ], 1 )

        space_enabled, self._free_space_value, self._free_space_unit = config.get_min_free_space()
        self._free_space_enabled = urwid.CheckBox( _('If free space is less than:'), space_enabled, on_state_change=self.flip_free_space_enabled )
        free_space_value_box = urwid.IntEdit( '', self._free_space_value )
        urwid.connect_signal( free_space_value_box, 'change', self.free_space_value_changed )
        free_space_units = []
        for key, value in sorted( config.MIN_FREE_SPACE_UNITS.items() ):
            if self._free_space_unit == key:
                urwid.RadioButton( free_space_units, value, True, self.free_space_unit_changed, key )
            else:
                urwid.RadioButton( free_space_units, value, False, self.free_space_unit_changed, key )
        space_unit_chooser = urwid.Pile( free_space_units )
        space_columns = urwid.Columns( [
            self._free_space_enabled,
            urwid.AttrWrap( free_space_value_box, 'edit_box', 'edit_focus' ),
            space_unit_chooser
            ], 1 )

        pile_list = [
            age_columns,
            urwid.Divider(),
            space_columns,
            urwid.Divider(),
            urwid.CheckBox( _('Smart remove'), config.get_smart_remove(), on_state_change=self.flip_smart_remove ),
            urwid.Padding( urwid.Text( _('- keep all snapshots from today and yesterday') ), left=4 ),
            urwid.Padding( urwid.Text( _('- keep one snapshot for the last week and one for two weeks ago') ), left=4 ),
            urwid.Padding( urwid.Text( _('- keep one snapshot per month for all previous months of this year and all months of the last year') ), left=4 ),
            urwid.Padding( urwid.Text( _('- keep one snapshot per year for all other years') ), left=4 ),
            urwid.Divider(),
            urwid.CheckBox( _("Don't remove named snapshots"), config.get_dont_remove_named_snapshots(), on_state_change=self.flip_remove_named )
            ]
        display_widget = urwid.Pile( pile_list )
        urwid.WidgetWrap.__init__( self, display_widget )

    def flip_remove_named( self, check_box, new_state ):
        self._config.set_dont_remove_named_snapshots( new_state )
        
    def flip_smart_remove( self, check_box, new_state ):
        self._config.set_smart_remove( new_state )
        
    def flip_free_space_enabled( self, check_box, new_state ):
        self._config.set_min_free_space( new_state, self._free_space_value, self._free_space_unit )
        
    def free_space_value_changed( self, edit, new_edit_text ):
        if new_edit_text == '':
            self._free_space_value = 0
        else:
            self._free_space_value = new_edit_text.strip()
        self._config.set_min_free_space( self._free_space_enabled.get_state(), self._free_space_value, self._free_space_unit )
        
    def free_space_unit_changed( self, check_box, new_state, user_data ):
        if new_state:
            self._free_space_unit = user_data
            self._config.set_min_free_space( self._free_space_enabled.get_state(), self._free_space_value, self._free_space_unit )
        
    def flip_old_enabled( self, check_box, new_state ):
        self._config.set_remove_old_snapshots( new_state, self._remove_old_value, self._remove_old_unit )

    def remove_old_value_changed( self, edit, new_edit_text ):
        if new_edit_text == '':
            self._remove_old_value = 0
        else:
            self._remove_old_value = new_edit_text.strip()
        self._config.set_remove_old_snapshots( self._remove_old_enabled.get_state(), self._remove_old_value, self._remove_old_unit )

    def remove_old_unit_changed( self, check_box, new_state, user_data ):
        if new_state:
            self._remove_old_unit = user_data
            self._config.set_remove_old_snapshots( self._remove_old_enabled.get_state(), self._remove_old_value, self._remove_old_unit )
