#    Back In Time
#    Copyright (C) 2010 Ryan Ahearn
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License along
#    with this program; if not, write to the Free Software Foundation, Inc.,
#    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
	

import urwid
import datetime
import gettext

import logger
import snapshots
import viewerwidget

_=gettext.gettext

class RestoreWidget(urwid.WidgetWrap):

    def __init__( self, main_win, config ):
        self._main_win = main_win
        self._config = config

        self._snapshots = snapshots.Snapshots( config )
        snapshots_pile = [
            urwid.Text( _('Snapshots') ),
            urwid.Divider(),
            ]
        snapshots_pile.extend( self.build_snapshots_pile() )

        display_widget = urwid.Columns( [
            urwid.Pile( snapshots_pile ),
            ( 'weight', 3, viewerwidget.ViewerWidget( main_win, config, self._snapshots ) )
            ], 1 )
        urwid.WidgetWrap.__init__( self, display_widget )

    def build_snapshots_pile( self ):
        snapshots_list = self._snapshots.get_snapshots_list()
        groups = []
        now = datetime.date.today()

        #today
        date = now
        groups.append( ( _('Today'), self._snapshots.get_snapshot_id( date ), [] ) )
        #yesterday
        date = now - datetime.timedelta( days = 1 )
        groups.append( ( _('Yesterday'), self._snapshots.get_snapshot_id( date ), [] ) )
        #this week
        date = now - datetime.timedelta( days = now.weekday() )
        groups.append( ( _('This week'), self._snapshots.get_snapshot_id( date ), [] ) )
        #last week
        date = now - datetime.timedelta( days = now.weekday() + 7 )
        groups.append( ( _('Last week'), self._snapshots.get_snapshot_id( date ), [] ) )
        #any other groups
        for snapshot_id in snapshots_list:
            found = False
            for group in groups:
                if snapshot_id >= group[1]:
                    group[2].append( snapshot_id )
                    found = True
                    break

            if not found:
                year = int( snapshot_id[0:4] )
                month = int( snapshot_id[4:6] )
                date = datetime.date( year, month, 1 )

                group_name = ''
                if year == now.year:
                    group_name = date.strftime( '%B' ).capitalize()
                else:
                    group_name = date.strftime( '%B, %Y' ).capitalize()

                groups.append( ( group_name, self._snapshots.get_snapshot_id( date ), [ snapshot_id ] ) )

        snapshots_buttons = []
        pile_list = [
            urwid.RadioButton( snapshots_buttons, _('Now'), self._main_win.is_selected_snapshot( '' ), self.change_snapshot, '' )
            ]
        for group in groups:
            if len( group[2] ) > 0:
                pile_list.append( urwid.Text( group[0] ) )
                for snapshot_id in group[2]:
                    display_name = self._snapshots.get_snapshot_display_id( snapshot_id )
                    user_name = self._snapshots.get_snapshot_name( snapshot_id )
                    if len( user_name ) > 0:
                        display_name += ' - ' + user_name
                    pile_list.append( urwid.RadioButton( snapshots_buttons, display_name, self._main_win.is_selected_snapshot( snapshot_id ), self.change_snapshot, snapshot_id ) )

        return pile_list

    def change_snapshot( self, check_box, new_state, user_data ):
        if new_state:
            self._main_win.selected_snapshot = user_data
            self._main_win.selected_snapshot_name = check_box.get_label()
            self._main_win.update_content( RestoreWidget( self._main_win, self._config ), 5 )
