#    Back In Time
#    Copyright (C) 2010 Ryan Ahearn
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License along
#    with this program; if not, write to the Free Software Foundation, Inc.,
#    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.


import os	
import os.path
import urwid
import gettext

import logger
import restorewidget
import copywidget
import snapshotswidget

_=gettext.gettext

class ViewerWidget(urwid.WidgetWrap):

    def __init__( self, main_win, config, snapshots ):
        self._main_win = main_win
        self._config = config
        self._snapshots = snapshots
        self._selected = ''

        if main_win.show_hidden:
            hidden_label = _('Hide hidden files')
        else:
            hidden_label = _('Show hidden files')
        self.build_fileview()
        pile_list = [
            urwid.Columns( [
                ( 'fixed', 6, urwid.AttrWrap( urwid.Button( _('Up'), self.up_directory ), 'button', 'button_focus' ) ),
                urwid.Text( main_win.current_directory, wrap='clip' )
                ], 1),
            urwid.Divider(),
            urwid.Columns( [
                ( 'fixed', 21, urwid.AttrWrap( urwid.Button( hidden_label, self.flip_hidden ), 'button', 'button_focus' ) ),
                ( 'fixed', 11, urwid.AttrWrap( urwid.Button( _('Restore'), self.restore ), 'button', 'button_focus' ) ),
                ( 'fixed', 8, urwid.AttrWrap( urwid.Button( _('Copy'), self.copy ), 'button', 'button_focus' ) ),
                ( 'fixed', 13,urwid.AttrWrap(  urwid.Button( _('Snapshots'), self.snapshots ), 'button', 'button_focus' ) )
                ], 1 ),
            urwid.Divider(),
            urwid.Columns( [ self.build_shortcuts(),
                             ( 'weight', 3, urwid.Pile( self._file_list ) ) ], 1 )
            ]
        display_widget = urwid.Pile( pile_list )
        urwid.WidgetWrap.__init__( self, display_widget )

    def build_fileview( self ):
        self._file_list = [
            urwid.Text( _('Files and Folders') ),
            urwid.Divider()
            ]

        sid = self._main_win.selected_snapshot
        
        full_path = self._snapshots.get_snapshot_path_to( sid, self._main_win.current_directory )

        if not self._snapshots.can_open_path( sid, full_path ):
            self._file_list.append( urwid.Text( _('This folder does not exist') ) )
            self._file_list.append( urwid.Text( _('in current snapshot !' ) ) )
            return

        directory = os.listdir( full_path )
        decorated = [ ( not os.path.isdir( os.path.join( full_path, file_name ) ), file_name ) for file_name in directory ]
        decorated.sort()
        restore_radios = []
        for is_file, file_name in decorated:
            if self._main_win.show_hidden or not file_name.startswith( '.' ):
                if is_file:
                    self._file_list.append( urwid.RadioButton( restore_radios, file_name, False, self.select_for_restore, file_name ) )
                else:
                    self._file_list.append( urwid.Columns( [
                        ( 'fixed', 4, urwid.RadioButton( restore_radios, '', False, self.select_for_restore, file_name ) ),
                        urwid.AttrWrap( urwid.Button( file_name, self.go_to_directory ), 'button', 'button_focus' )
                        ], 0 ) )
        

    def select_for_restore( self, radio_button, new_state, user_data ):
        if new_state:
            self._selected = os.path.join( self._main_win.current_directory, user_data )
        
    def go_to_directory( self, button ):
        new_directory = os.path.join( self._main_win.current_directory, button.get_label() )
        self._main_win.update_current_directory( new_directory )

    def build_shortcuts( self ):
        pile_list = [ urwid.Text( _('Shortcuts') ) ]

        included_folders = self._config.get_include_folders()
        for label in included_folders:
            pile_list.append( urwid.AttrWrap( urwid.Button( label, self.go_to_shortcut ), 'button', 'button_focus' ) )

        return urwid.Pile( pile_list )

    def go_to_shortcut( self, button ):
        self._main_win.update_current_directory( button.get_label() )

    def up_directory( self, button ):
        self._main_win.update_current_directory( os.path.dirname( self._main_win.current_directory ) )

    def flip_hidden( self, button ):
        self._main_win.show_hidden = not self._main_win.show_hidden
        self._main_win.update_content( restorewidget.RestoreWidget( self._main_win, self._config ), 5 )

    def restore( self, button ):
        if self._main_win.selected_snapshot != '' and self._selected != '':
            self._snapshots.restore( self._main_win.selected_snapshot, self._selected )

    def copy( self, button ):
        if self._main_win.selected_snapshot != '' and self._selected != '':
            source_path = self._snapshots.get_snapshot_path_to( self._main_win.selected_snapshot, self._selected )
            self._main_win.update_content( copywidget.CopyWidget( self._main_win, self._config, source_path ), 5 )

    def snapshots( self, button ):
        if self._selected != '':
            self._main_win.update_content( snapshotswidget.SnapshotsWidget( self._main_win, self._config, self._snapshots, self._selected ), 5 )
            
